@@ -420,7 +420,8 @@ class MagicDAQClient64Bit(Client64):
         '''
         Method returns the number of pulses that have been counted.
 
-        Returns: int : number of pulses that have been counted.
+        Returns:
+            pulse_count: int : number of pulses that have been counted.
 
         ***Example Usage***
         daq_one = easydaq.DAQDevice()
